==> soqt_1.0.2.orig.tar.gz: SoQt-1.0.2/src/Inventor/Qt/viewers/SoQtExaminerViewerP.h <==
#ifndef SOQTEXAMINERVIEWERP_H
#define SOQTEXAMINERVIEWERP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2003 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no>.
 *
\**************************************************************************/

#ifndef SOQT_INTERNAL
#error this is a private header file
#endif /* !SOQT_INTERNAL */

#include <qobject.h>
#include <Inventor/SbBasic.h>
#include <Inventor/Qt/viewers/SoGuiExaminerViewerP.h>

class SoQtExaminerViewer;

// ************************************************************************

// This class contains private data and methods used within the
// SoQtExaminerViewer class.

class SoQtExaminerViewerP : public QObject, public SoGuiExaminerViewerP
{
  Q_OBJECT

public:
  SoQtExaminerViewerP(SoQtExaminerViewer * publ);
  ~SoQtExaminerViewerP();

  void constructor(SbBool buildNow);

  QPixmap * orthopixmap, * perspectivepixmap;
  class QPushButton * cameratogglebutton;

public slots:
  // viewer buttons row:
  void cameratoggleClicked(void);
};

// ************************************************************************

#endif // ! SOQTEXAMINERVIEWERP_H

==> soqt_1.2.0.orig.tar.gz: SoQt-1.2.0/src/Inventor/Qt/viewers/SoQtExaminerViewerP.h <==
#ifndef SOQTEXAMINERVIEWERP_H
#define SOQTEXAMINERVIEWERP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef SOQT_INTERNAL
#error this is a private header file
#endif /* !SOQT_INTERNAL */

#include <qobject.h>
#include <Inventor/SbBasic.h>
#include <Inventor/Qt/viewers/SoGuiExaminerViewerP.h>

class SoQtExaminerViewer;

// ************************************************************************

// This class contains private data and methods used within the
// SoQtExaminerViewer class.

class SoQtExaminerViewerP : public QObject, public SoGuiExaminerViewerP
{
  Q_OBJECT

public:
  SoQtExaminerViewerP(SoQtExaminerViewer * publ);
  ~SoQtExaminerViewerP();

  void constructor(SbBool buildNow);

  QPixmap * orthopixmap, * perspectivepixmap;
  class QPushButton * cameratogglebutton;

public slots:
  // viewer buttons row:
  void cameratoggleClicked(void);
};

// ************************************************************************

#endif // ! SOQTEXAMINERVIEWERP_H
